==> kblogger_0.6.2.orig.tar.gz: kblogger-0.6.2/src/kbloggerlinkdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Weilbach   *
 *   christian_weilbach@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "kbloggerlinkdialog.h"
#include "klineedit.h"

KBloggerLinkDialog::KBloggerLinkDialog(QWidget *parent, const char *name)
    :KBloggerLinkDialogBlank(parent, name)
{
}

void KBloggerLinkDialog::addLinkSlot()
{
	emit addLink( targetLineEdit->text(), nameLineEdit->text() );
	targetLineEdit->setText( "" );
	nameLineEdit->setText( "" );
	this->hide();
}


#include "kbloggerlinkdialog.moc"

==> kblogger_0.6.5.orig.tar.gz: kblogger-0.6.5/src/kbloggerlinkdialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Weilbach   *
 *   christian_weilbach@web.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "kbloggerlinkdialog.h"

#include <klineedit.h>
#include <qregexp.h>
KBloggerLinkDialog::KBloggerLinkDialog(QWidget *parent, const char *name)
    :KBloggerLinkDialogBlank(parent, name)
{
}

void KBloggerLinkDialog::setName(const QString &linkName)
{ 
  nameLineEdit->setText(sanitize(linkName));
}

void KBloggerLinkDialog::addLinkSlot()
{
	emit addLink( targetLineEdit->text(), nameLineEdit->text() );
	targetLineEdit->setText( "" );
	nameLineEdit->setText( "" );
	this->hide();
}

QString KBloggerLinkDialog::sanitize(const QString& dirtyString)
{
  QRegExp rx("<[-!/a-zA-Z]+>");
  QString cleanedString=dirtyString;
  return cleanedString.remove(rx);
}

#include "kbloggerlinkdialog.moc"
